package expressionprog;

/**
 * A program item that represents assignment of a value to a variable.
 * An assignment is also an expression, whose value is the same value
 * that is assigned to the variable.  To execute an assignment, a
 * value is popped from the stack and assigned to the variable, and
 * then the same value is pushed back onto the stack.
 */
public class Assign extends ProgramItem {
	
	private final String name;
	
	public Assign(String variableName) {
		if (variableName == null)
			throw new IllegalArgumentException("null names not allowed");
		name = variableName;
	}
	
	/**
	 * Returns the name of the variable to which the value should be assigned.
	 */
	public String getName() {
		return name;
	}

	/**
	 * Returns a string describing the action of this program item on a stack.
	 */
	public String toString() {
		return "Assign value to variable " + name;
	}

}
