package expressionprog;

/**
 * A program item that represents a function of one variable,
 * such as sin or abs.  The argument of the function is popped
 * from the stack, the function is applied, and the result is
 * pushed back onto the stack.
 */
public class Function extends ProgramItem {
	
	private final String name;
	
	public Function(String functioneName) {
		if (functioneName == null)
			throw new IllegalArgumentException("null names not allowed");
		name = functioneName;
	}
	
	/**
	 * Returns the name of the function that this program item represents.
	 */
	public String getName() {
		return name;
	}

	/**
	 * Returns a string describing the action of this program item on a stack.
	 */
	public String toString() {
		return "Apply function " + name;
	}

}
